@@ -10,6 +10,7 @@ import platform
 import requests
 import six
 import time
+import warnings
 from io import BytesIO
 from itertools import chain
 from hashlib import sha256
@@ -40,6 +41,7 @@ TRAIN_CA_CERT = pkg_resources.resource_filename('mesh_client', "nhs-train-ca-bun
 LIVE_CA_CERT = pkg_resources.resource_filename('mesh_client', "nhs-live-root-ca.pem")
 OPENTEST_CA_CERT = pkg_resources.resource_filename('mesh_client', "nhs-opt-ca-bundle.pem")
 DIGICERT_CA_CERT = pkg_resources.resource_filename('mesh_client', "nhs-digicert-ca-bundle.pem")
+IG_INT_CA_CERT = pkg_resources.resource_filename('mesh_client', "nhs-ig-int-ca-bundle.pem")
 
 
 _OPTIONAL_HEADERS = {
@@ -79,8 +81,7 @@ NHS_TRAIN_ENDPOINT = Endpoint('https://msg.train.spine2.ncrs.nhs.uk', TRAIN_CA_C
 NHS_LIVE_ENDPOINT = Endpoint('https://mesh-sync.national.ncrs.nhs.uk', LIVE_CA_CERT, None)
 NHS_OPENTEST_ENDPOINT = Endpoint('https://192.168.128.11', OPENTEST_CA_CERT, None)
 NHS_INTERNET_GATEWAY_ENDPOINT = Endpoint('https://mesh.spineservices.nhs.uk', DIGICERT_CA_CERT, None)
-# Internet gateway int serves up an invalid certificate, so validation has to be disabled
-NHS_INTERNET_GATEWAY_INT_ENDPOINT = Endpoint('https://mesh.intspineservices.nhs.uk', False, None)
+NHS_INTERNET_GATEWAY_INT_ENDPOINT = Endpoint('https://msg.intspineservices.nhs.uk', IG_INT_CA_CERT, None)
 
 
 class MeshError(Exception):
@@ -166,6 +167,7 @@ class MeshClient(object):
         self._transparent_compress = transparent_compress
         self._max_chunk_retries = max_chunk_retries
         self._timeout = timeout
+        self._close_called = False
 
     def handshake(self):
         """
@@ -201,6 +203,17 @@ class MeshClient(object):
         response.raise_for_status()
         return response.json()
 
+    def lookup_endpoint(self, organisation_code, workflow_id):
+        """
+        Lookup a mailbox by organisation code and workflow id.
+        Returns a dictionary, in much the same format that MESH provides it.
+        """
+        response = self._session.get(
+            "{}/endpointlookup/mesh/{}/{}".format(self._url, organisation_code, workflow_id),
+            timeout=self._timeout)
+        response.raise_for_status()
+        return response.json()
+
     def list_messages(self):
         """
         List all messages in user's inbox. Returns a list of message_ids
@@ -372,12 +385,20 @@ class MeshClient(object):
             yield self.retrieve_message(msg_id)
 
     def close(self):
-        if self._session is not None:
-            self._session.close()
-            self._session = None
+        self._close_called = True
+        self._session.close()
 
     def __del__(self):
-        self.close()
+        if not self._close_called:
+            warnings.warn(
+                "The API of MeshClient changed in mesh_client 1.0. Each"
+                " MeshClient instance must now be closed when the instance is"
+                " no longer needed. This can be achieved by using the close"
+                " method, or by using MeshClient in a with block. The"
+                " connection pool will be closed for you by the destructor"
+                " on this occasion, but you should not rely on this."
+            )
+            self.close()
 
     def __enter__(self):
         return self
